class Welcome:
    def __init__(self) -> None:
        pass

    def hello(self, help="Prompt Greeting"):
        return "MrPeace the only cli to peace!"
